@@ -98,15 +98,14 @@ void ImportAddressbookJob::restoreResources()
                 const KArchiveEntry *fileResouceEntry = mArchiveDirectory->entry(value.akonadiConfigFile);
                 if (fileResouceEntry && fileResouceEntry->isFile()) {
                     const KArchiveFile *file = static_cast<const KArchiveFile *>(fileResouceEntry);
-                    file->copyTo(copyToDirName);
+                    copyArchiveFileTo(file, copyToDirName);
                     QString resourceName(file->name());
 
-                    QString filename(file->name());
-                    //TODO adapt filename otherwise it will use all the time the same filename.
+                    QString filename(resourceName);
                     KSharedConfig::Ptr resourceConfig = KSharedConfig::openConfig(copyToDirName + QLatin1Char('/') + resourceName);
 
                     //TODO fix default path
-                    const QString newUrl = Utils::adaptResourcePath(resourceConfig, QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/contacts"));
+                    const QString newUrl = Utils::adaptResourcePath(resourceConfig, QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/contacts"));
                     QFileInfo newUrlInfo(newUrl);
                     const QString dataFile = value.akonadiResources;
                     const KArchiveEntry *dataResouceEntry = mArchiveDirectory->entry(dataFile);
@@ -122,7 +121,7 @@ void ImportAddressbookJob::restoreResources()
                         const KArchiveEntry *akonadiAgentConfigEntry = mArchiveDirectory->entry(agentConfigFile);
                         if (akonadiAgentConfigEntry->isFile()) {
                             const KArchiveFile *file = static_cast<const KArchiveFile *>(akonadiAgentConfigEntry);
-                            file->copyTo(copyToDirName);
+                            copyArchiveFileTo(file, copyToDirName);
                             resourceName = file->name();
                             filename = Utils::akonadiAgentName(copyToDirName + QLatin1Char('/') + resourceName);
                         }
@@ -133,12 +132,12 @@ void ImportAddressbookJob::restoreResources()
                     } else if (value.akonadiConfigFile.contains(QLatin1String("akonadi_contacts_resource_"))) {
                         instanceType = QStringLiteral("akonadi_contacts_resource");
                     } else {
-                        qCDebug(PIMSETTINGEXPORTERCORE_LOG) << " not supported" << value.akonadiConfigFile;
+                        qCWarning(PIMDATAEXPORTERCORE_LOG) << " not supported" << value.akonadiConfigFile;
                     }
 
                     const QString newResource = mCreateResource->createResource(instanceType, filename, settings, true);
                     infoAboutNewResource(newResource);
-                    qCDebug(PIMSETTINGEXPORTERCORE_LOG) << " newResource" << newResource;
+                    qCDebug(PIMDATAEXPORTERCORE_LOG) << " newResource" << newResource;
                     listResource << newResource;
                 }
             }
@@ -150,7 +149,7 @@ void ImportAddressbookJob::restoreResources()
     startSynchronizeResources(listResource);
 }
 
-void ImportAddressbookJob::addSpecificResourceSettings(KSharedConfig::Ptr resourceConfig, const QString &resourceName, QMap<QString, QVariant> &settings)
+void ImportAddressbookJob::addSpecificResourceSettings(const KSharedConfig::Ptr &resourceConfig, const QString &resourceName, QMap<QString, QVariant> &settings)
 {
     if (resourceName == QLatin1String("akonadi_vcard_resource")) {
         KConfigGroup general = resourceConfig->group(QStringLiteral("General"));
@@ -200,12 +199,7 @@ void ImportAddressbookJob::importkaddressBookConfig(const KArchiveFile *file, co
     copyToFile(file, config, filename, prefix);
     KSharedConfig::Ptr kaddressBookConfig = KSharedConfig::openConfig(config);
 
-    const QString collectionViewCheckStateStr(QStringLiteral("CollectionViewCheckState"));
-    if (kaddressBookConfig->hasGroup(collectionViewCheckStateStr)) {
-        KConfigGroup group = kaddressBookConfig->group(collectionViewCheckStateStr);
-        const QString selectionKey(QStringLiteral("Selection"));
-        convertRealPathToCollectionList(group, selectionKey, true);
-    }
+    convertCollectionListStrToAkonadiId(kaddressBookConfig, QStringLiteral("CollectionViewCheckState"), QStringLiteral("Selection"), true);
 
     const QString collectionViewStateStr(QStringLiteral("CollectionViewState"));
     if (kaddressBookConfig->hasGroup(collectionViewStateStr)) {
