@@ -70,7 +70,7 @@ void ImportAlarmJob::slotNextStep()
         } else if (type == Utils::Config) {
             restoreConfig();
         } else {
-            qCDebug(PIMSETTINGEXPORTERCORE_LOG) << Q_FUNC_INFO << " not supported type " << type;
+            qCDebug(PIMDATAEXPORTERCORE_LOG) << Q_FUNC_INFO << " not supported type " << type;
             slotNextStep();
         }
     } else {
@@ -99,12 +99,12 @@ void ImportAlarmJob::restoreResources()
                 const KArchiveEntry *fileResouceEntry = mArchiveDirectory->entry(value.akonadiConfigFile);
                 if (fileResouceEntry && fileResouceEntry->isFile()) {
                     const KArchiveFile *file = static_cast<const KArchiveFile *>(fileResouceEntry);
-                    file->copyTo(copyToDirName);
+                    copyArchiveFileTo(file, copyToDirName);
                     QString resourceName(file->name());
 
-                    QString filename(file->name());
+                    QString filename(resourceName);
                     //TODO adapt filename otherwise it will use all the time the same filename.
-                    qCDebug(PIMSETTINGEXPORTERCORE_LOG) << " filename :" << filename;
+                    qCDebug(PIMDATAEXPORTERCORE_LOG) << " filename :" << filename;
 
                     KSharedConfig::Ptr resourceConfig = KSharedConfig::openConfig(copyToDirName + QLatin1Char('/') + resourceName);
 
@@ -125,7 +125,7 @@ void ImportAlarmJob::restoreResources()
                         const KArchiveEntry *akonadiAgentConfigEntry = mArchiveDirectory->entry(agentConfigFile);
                         if (akonadiAgentConfigEntry->isFile()) {
                             const KArchiveFile *file = static_cast<const KArchiveFile *>(akonadiAgentConfigEntry);
-                            file->copyTo(copyToDirName);
+                            copyArchiveFileTo(file, copyToDirName);
                             resourceName = file->name();
                             filename = Utils::akonadiAgentName(copyToDirName + QLatin1Char('/') + resourceName);
                         }
@@ -134,7 +134,7 @@ void ImportAlarmJob::restoreResources()
                     const QString newResource = mCreateResource->createResource(archiveNameType, filename, settings, true);
                     infoAboutNewResource(newResource);
                     listResource << newResource;
-                    qCDebug(PIMSETTINGEXPORTERCORE_LOG) << " newResource" << newResource;
+                    qCDebug(PIMDATAEXPORTERCORE_LOG) << " newResource" << newResource;
                 }
             }
         }
@@ -176,12 +176,7 @@ void ImportAlarmJob::importkalarmConfig(const KArchiveFile *kalarmFile, const QS
     copyToFile(kalarmFile, kalarmrc, filename, prefix);
     KSharedConfig::Ptr kalarmConfig = KSharedConfig::openConfig(kalarmrc);
 
-    const QString collectionsStr(QStringLiteral("Collections"));
-    if (kalarmConfig->hasGroup(collectionsStr)) {
-        KConfigGroup group = kalarmConfig->group(collectionsStr);
-        const QString selectionKey(QStringLiteral("FavoriteCollectionIds"));
-        convertRealPathToCollectionList(group, selectionKey, false);
-    }
+    convertCollectionListStrToAkonadiId(kalarmConfig, QStringLiteral("Collections"), QStringLiteral("FavoriteCollectionIds"), false);
 
     kalarmConfig->sync();
 }
