@@ -38,7 +38,7 @@ protected:
     void slotNextStep() override;
 
 private:
-    bool isAConfigFile(const QString &name) const override;
+    Q_REQUIRED_RESULT bool isAConfigFile(const QString &name) const override;
     void importkorganizerConfig(const KArchiveFile *file, const QString &config, const QString &filename, const QString &prefix);
     void importeventViewConfig(const KArchiveFile *file, const QString &config, const QString &filename, const QString &prefix);
     void restoreResources();
