@@ -44,7 +44,7 @@ void ExportNotesJob::start()
 {
     Q_EMIT title(i18n("Start export KNotes settings..."));
     createProgressDialog(i18n("Export KNotes settings"));
-    if (mTypeSelected & Utils::Data) {
+    if (mTypeSelected & Utils::Resources) {
         QTimer::singleShot(0, this, &ExportNotesJob::slotCheckBackupResource);
     } else if (mTypeSelected & Utils::Config) {
         QTimer::singleShot(0, this, &ExportNotesJob::slotCheckBackupConfig);
@@ -55,10 +55,10 @@ void ExportNotesJob::start()
 
 void ExportNotesJob::backupTheme()
 {
-    const QString notesThemeDir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/knotes/print/");
+    const QString notesThemeDir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/knotes/print/");
     QDir notesThemeDirectory(notesThemeDir);
     if (notesThemeDirectory.exists()) {
-        const bool notesDirAdded = archive()->addLocalDirectory(notesThemeDir, Utils::dataPath() +  QLatin1String("knotes/print"));
+        const bool notesDirAdded = archive()->addLocalDirectory(notesThemeDir, Utils::dataPath() +  QStringLiteral("knotes/print"));
         if (!notesDirAdded) {
             Q_EMIT error(i18n("\"%1\" directory cannot be added to backup file.", notesThemeDir));
         }
@@ -122,7 +122,7 @@ void ExportNotesJob::slotWriteNextArchiveResource()
                     connect(resourceJob, &ExportResourceArchiveJob::terminated, this, &ExportNotesJob::slotNoteJobTerminated);
                     resourceJob->start();
                 } else {
-                    qCDebug(PIMSETTINGEXPORTERCORE_LOG) << "Url is empty for " << identifier;
+                    qCDebug(PIMDATAEXPORTERCORE_LOG) << "Url is empty for " << identifier;
                     QTimer::singleShot(0, this, &ExportNotesJob::slotNoteJobTerminated);
                 }
             } else {
