@@ -30,8 +30,8 @@
 #include <AkonadiCore/entitymimetypefiltermodel.h>
 #include <AkonadiCore/changerecorder.h>
 #include <Akonadi/Notes/NoteUtils>
-#include <KCalCore/Todo>
-#include <KCalCore/Event>
+#include <KCalendarCore/Todo>
+#include <KCalendarCore/Event>
 #include <KSharedConfig>
 
 //Same element as kalarmcal
@@ -48,8 +48,8 @@ PimDataExporterKernel::PimDataExporterKernel(QObject *parent)
     mFolderCollectionMonitor = new MailCommon::FolderCollectionMonitor(session, this);
     mFolderCollectionMonitor->monitor()->setMimeTypeMonitored(KContacts::Addressee::mimeType(), true);
     mFolderCollectionMonitor->monitor()->setMimeTypeMonitored(KContacts::ContactGroup::mimeType(), true);
-    mFolderCollectionMonitor->monitor()->setMimeTypeMonitored(KCalCore::Todo::todoMimeType(), true);
-    mFolderCollectionMonitor->monitor()->setMimeTypeMonitored(KCalCore::Event::eventMimeType(), true);
+    mFolderCollectionMonitor->monitor()->setMimeTypeMonitored(KCalendarCore::Todo::todoMimeType(), true);
+    mFolderCollectionMonitor->monitor()->setMimeTypeMonitored(KCalendarCore::Event::eventMimeType(), true);
     mFolderCollectionMonitor->monitor()->setMimeTypeMonitored(Akonadi::NoteUtils::noteMimeType(), true);
     mFolderCollectionMonitor->monitor()->setMimeTypeMonitored(MIME_ACTIVE);
     mFolderCollectionMonitor->monitor()->setMimeTypeMonitored(MIME_ARCHIVED);
