@@ -18,7 +18,7 @@
 */
 
 #include "templateselection.h"
-#include "pimsettingexportcore_debug.h"
+#include "pimdataexportcore_debug.h"
 #include <QFile>
 #include <QXmlStreamWriter>
 
@@ -67,7 +67,7 @@ QHash<Utils::AppsType, Utils::importExportParameters> TemplateSelection::loadTem
     }
     QFile file(path);
     if (!file.open(QIODevice::ReadOnly|QIODevice::Text)) {
-        qCDebug(PIMSETTINGEXPORTERCORE_LOG) << "Unable to load file:" << path;
+        qCDebug(PIMDATAEXPORTERCORE_LOG) << "Unable to load file:" << path;
         return {};
     } else {
         mStreamReader = new QXmlStreamReader(&file);
@@ -75,7 +75,8 @@ QHash<Utils::AppsType, Utils::importExportParameters> TemplateSelection::loadTem
 
     QHash<Utils::AppsType, Utils::importExportParameters> value;
     if (mStreamReader->readNextStartElement()) {
-        if (mStreamReader->name() == QLatin1String("pimsettingexporter")) {
+        //Compatibility with old version
+        if ((mStreamReader->name() == QLatin1String("pimsettingexporter")) || (mStreamReader->name() == QLatin1String("pimdataexporter"))) {
             while (mStreamReader->readNextStartElement()) {
                 Utils::AppsType type = Utils::Unknown;
                 if (mStreamReader->name() == QLatin1String("kmail")) {
@@ -105,10 +106,10 @@ QHash<Utils::AppsType, Utils::importExportParameters> TemplateSelection::loadTem
                 }
             }
         } else {
-            qCDebug(PIMSETTINGEXPORTERCORE_LOG) << "Toplevel xml is not correct";
+            qCDebug(PIMDATAEXPORTERCORE_LOG) << "Toplevel xml is not correct";
         }
     } else {
-        qCDebug(PIMSETTINGEXPORTERCORE_LOG) << "Impossible to parse file";
+        qCDebug(PIMDATAEXPORTERCORE_LOG) << "Impossible to parse file";
     }
 
     return value;
@@ -150,7 +151,7 @@ void TemplateSelection::createTemplate(const QHash<Utils::AppsType, Utils::impor
     mStreamWriter->setAutoFormattingIndent(2);
     mStreamWriter->writeStartDocument();
 
-    mStreamWriter->writeStartElement(QStringLiteral("pimsettingexporter"));
+    mStreamWriter->writeStartElement(QStringLiteral("pimdataexporter"));
 
     QHash<Utils::AppsType, Utils::importExportParameters>::const_iterator i = stored.constBegin();
     while (i != stored.constEnd()) {
@@ -186,7 +187,7 @@ void TemplateSelection::createTemplate(const QHash<Utils::AppsType, Utils::impor
             mStreamWriter->writeEndElement();
             break;
         case Utils::Unknown:
-            qCCritical(PIMSETTINGEXPORTERCORE_LOG) << "Code must not use this enum here";
+            qCCritical(PIMDATAEXPORTERCORE_LOG) << "Code must not use this enum here";
             break;
         }
         ++i;
