@@ -30,13 +30,13 @@
 
 #include <QTreeWidgetItem>
 #include <QHeaderView>
-#include "gui/pimsettingexportgui_debug.h"
+#include "gui/pimdataexportgui_debug.h"
 #include <QPointer>
 
-SelectionTypeTreeWidget::SelectionTypeTreeWidget(QWidget *parent)
+SelectionTypeTreeWidget::SelectionTypeTreeWidget(bool backupData, QWidget *parent)
     : QTreeWidget(parent)
 {
-    initialize();
+    initialize(backupData);
     expandAll();
     header()->hide();
 }
@@ -45,7 +45,7 @@ SelectionTypeTreeWidget::~SelectionTypeTreeWidget()
 {
 }
 
-void SelectionTypeTreeWidget::initialize()
+void SelectionTypeTreeWidget::initialize(bool backupData)
 {
     mKmailItem = new QTreeWidgetItem(this);
     mKmailItem->setCheckState(0, Qt::Checked);
@@ -77,8 +77,11 @@ void SelectionTypeTreeWidget::initialize()
     mKNotesItem = new QTreeWidgetItem(this);
     mKNotesItem->setText(0, Utils::appTypeToI18n(Utils::KNotes));
     mKNotesItem->setCheckState(0, Qt::Checked);
+    createSubItem(mKNotesItem, Utils::Resources);
     createSubItem(mKNotesItem, Utils::Config);
-    createSubItem(mKNotesItem, Utils::Data);
+    if (!backupData) {
+        createSubItem(mKNotesItem, Utils::Data);
+    }
 
     mAkregatorItem = new QTreeWidgetItem(this);
     mAkregatorItem->setText(0, Utils::appTypeToI18n(Utils::Akregator));
@@ -306,7 +309,11 @@ void SelectionTypeTreeWidget::loadFileName(const QString &fileName)
 
 void SelectionTypeTreeWidget::loadDefaultTemplate()
 {
-    const QString ret = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("/pimsettingexporter/defaulttemplate.xml"));
+    //Keep old name for compatibility
+    QString ret = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("/pimsettingexporter/defaulttemplate.xml"));
+    if (ret.isEmpty()) {
+        ret = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("/pimdataexporter/defaulttemplate.xml"));
+    }
     if (!ret.isEmpty()) {
         loadFileName(ret);
     }
@@ -348,7 +355,7 @@ QString SelectionTypeTreeWidget::templateSelectionToString()
 void SelectionTypeTreeWidget::saveAsDefaultTemplate()
 {
     const QString templateStr = templateSelectionToString();
-    QString ret = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/pimsettingexporter/");
+    QString ret = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/pimdataexporter/");
     QDir().mkpath(ret);
 
     PimCommon::Util::saveToFile(ret + QStringLiteral("defaulttemplate.xml"), templateStr);
